package WebGUI::i18n::German::Asset_Collaboration;
use utf8;
our $I18N = {
  'Link Description' => {
    'lastUpdated' => '1234737713',
    'message' => 'Link-Beschreibung'
  },
  'Link URL' => {
    'lastUpdated' => '1234737724',
    'message' => 'Link-URL'
  },
  'List All Links' => {
    'lastUpdated' => '1234737736',
    'message' => 'Alle Links anzeigen'
  },
  'Unsubscribe from %s' => {
    'lastUpdated' => '1274268200',
    'message' => 'Abbestellen von %s'
  },
  'You have been unsubscribed' => {
    'lastUpdated' => '1274268216',
    'message' => 'Ihr Abo wurde abbestellt.'
  },
  'add' => {
    'lastUpdated' => '1157903572',
    'message' => 'Hinzufügen'
  },
  'add.label' => {
    'lastUpdated' => '1178626667',
    'message' => 'Das Wort &quot;Hinzufügen&quot;'
  },
  'add.url' => {
    'lastUpdated' => '1179742713',
    'message' => 'URL, um einen neuen Thread hinzuzufügen.'
  },
  'addlink' => {
    'lastUpdated' => '1178626676',
    'message' => 'Einen Link hinzufügen'
  },
  'addlink.label' => {
    'lastUpdated' => '1157903648',
    'message' => 'Der Ausdruck &quot;Einen Link hinzufügen&quot;.<br />'
  },
  'addquestion' => {
    'lastUpdated' => '1178626686',
    'message' => 'Eine Frage hinzufügen'
  },
  'addquestion.label' => {
    'lastUpdated' => '1157903672',
    'message' => 'Der Ausdruck &quot;Eine Frage hinzufügen&quot;.<br />'
  },
  'allow replies' => {
    'lastUpdated' => '1168223728',
    'message' => 'Antworten zulassen.'
  },
  'allow replies description' => {
    'lastUpdated' => '1157903731',
    'message' => 'Wählen Sie &quot;Nein&quot; aus, um Anworten zu diesem Beitrag zu unterbinden.<br />'
  },
  'answer' => {
    'lastUpdated' => '1157903742',
    'message' => 'Antwort'
  },
  'answer.label' => {
    'lastUpdated' => '1178626694',
    'message' => 'Das Wort &quot;Anwtwort&quot;.'
  },
  'approval workflow' => {
    'lastUpdated' => '1179742761',
    'message' => 'Freigabe Workflow'
  },
  'approval workflow description' => {
    'lastUpdated' => '1179742814',
    'message' => 'Wählen Sie einen Workflow, der ausgeführt wird, falls ein neuer Post abgeschickt wird.'
  },
  'archive' => {
    'lastUpdated' => '1168864134',
    'message' => 'Archivieren'
  },
  'archive after' => {
    'lastUpdated' => '1178626706',
    'message' => 'Archiviere nach'
  },
  'archive after description' => {
    'lastUpdated' => '1168864357',
    'message' => 'Zeitspanne nach dem letzten Update eines Betrags, nachdem dieser archiviert wird.<br />'
  },
  'ascending' => {
    'lastUpdated' => '1168223695',
    'message' => 'Aufsteigend'
  },
  'asset not committed' => {
    'lastUpdated' => '1224834997',
    'message' => '<h1>Fehler!</h1><p>Sie müssen dieses Collaboration System committen, bevor Sie einen neuen Thread starten können.&nbsp;</p>'
  },
  'assetName' => {
    'lastUpdated' => '1178626714',
    'message' => 'Collaboration System'
  },
  'attachment' => {
    'lastUpdated' => '1157904439',
    'message' => 'Anhang'
  },
  'attachment.label' => {
    'lastUpdated' => '1179742867',
    'message' => 'Das Wort "Attachment".'
  },
  'attachment.length' => {
    'lastUpdated' => '1178626722',
    'message' => 'Größe Anhang in Bytes.'
  },
  'attachment.path' => {
    'lastUpdated' => '1178626729',
    'message' => 'Pfad im Dateisystem zu diesem Anhang.'
  },
  'attachment.url' => {
    'lastUpdated' => '1178626736',
    'message' => 'URL zu diesem Anhang.'
  },
  'attachmentLoop' => {
    'lastUpdated' => '1168864543',
    'message' => 'Schleife, die alle Anhänge in diesem Beitrag enth&auml;lt.'
  },
  'attachment_thumbnail' => {
    'lastUpdated' => '1179742921',
    'message' => 'URL zum Thumbnail für diesen Anhang. Dateien werden je nach Dateityp durch ein Icon gekennzeichnet. Bilder haben ein echtes Thumbnail.'
  },
  'attachments/post' => {
    'lastUpdated' => '1178626744',
    'message' => 'Anhänge pro Beitrag.'
  },
  'attachments/post description' => {
    'lastUpdated' => '1168864580',
    'message' => 'Wie viele Anhänge dürfen pro Beitrag hinzugef&uuml;gt werden?<br />'
  },
  'author' => {
    'lastUpdated' => '1157903796',
    'message' => 'Der Nutzername des Beitragsverfassers '
  },
  'auto subscribe to thread' => {
    'lastUpdated' => '1179744882',
    'message' => 'Thread automatisch abonnieren?'
  },
  'auto subscribe to thread help' => {
    'lastUpdated' => '1180075332',
    'message' => 'Falls ein Benutzer weder einen Thread noch ein CS abonniert hat und dieser dann per Email postet, soll der den Thread dann automatisch abonnieren? Falls hier "Ja" gewählt wird, wird der Thread automatisch abonniert. Dieses Feld ist nur wirksam, falls \'Abonnement erforderlich für das posten per Email?\' auf "Nein" gesetzt ist.'
  },
  'avatar.url' => {
    'lastUpdated' => '1179745109',
    'message' => 'URL zum Avatar für den Besitzer des Posts, falls Avatare aktiviert sind und der Benutzer einen Avatar besitzt.'
  },
  'back' => {
    'lastUpdated' => '1157903810',
    'message' => 'Zurück'
  },
  'back.label' => {
    'lastUpdated' => '1286873903',
    'message' => 'Zurück'
  },
  'back.url' => {
    'lastUpdated' => '1179745169',
    'message' => 'URL, um zur Hauptansicht dieses Collaboration Assets zurückzukehren.'
  },
  'body' => {
    'lastUpdated' => '1179745196',
    'message' => 'Body'
  },
  'body.label' => {
    'lastUpdated' => '1179745207',
    'message' => 'Das Wort "Body".'
  },
  'by' => {
    'lastUpdated' => '1180075340',
    'message' => 'Von'
  },
  'by.label' => {
    'lastUpdated' => '1179745226',
    'message' => 'Das Wort "By"'
  },
  'captcha label' => {
    'lastUpdated' => '1253184975',
    'message' => 'Geben Sie die nachfolgende Zeichenfolge ein'
  },
  'captcha_label' => {
    'lastUpdated' => '1257324341',
    'message' => 'Das Wort "Captcha"'
  },
  'close' => {
    'lastUpdated' => '1179745252',
    'message' => 'Schließen '
  },
  'close.label' => {
    'lastUpdated' => '1179745262',
    'message' => 'Das Wort "Close".'
  },
  'closed' => {
    'lastUpdated' => '1236959300',
    'message' => 'Abgeschlossen '
  },
  'closed.label' => {
    'lastUpdated' => '1179745299',
    'message' => 'Das Wort "Closed".'
  },
  'collab link' => {
    'lastUpdated' => '1179745315',
    'message' => 'URL zum Collaboration System.'
  },
  'collaboration post list template variables title' => {
    'lastUpdated' => '1178710958',
    'message' => 'Collaboration, Beitrag Liste Template Variablen'
  },
  'collaboration rss template title' => {
    'lastUpdated' => '1192978301',
    'message' => 'Collaboration RSS Template Variable
'
  },
  'collaboration search template title' => {
    'lastUpdated' => '1192978308',
    'message' => 'Collaboration Such Template Variable'
  },
  'collaboration template labels title' => {
    'lastUpdated' => '1192978315',
    'message' => 'Collaboration Template Labels Variable'
  },
  'collaboration template title' => {
    'lastUpdated' => '1179751009',
    'message' => 'Collaboration Template'
  },
  'collaboration unsubscribe template title' => {
    'lastUpdated' => '1274268285',
    'message' => 'Collaboration System Abbestellen-Template'
  },
  'collaborationAssetId' => {
    'lastUpdated' => '1179751085',
    'message' => 'Die assetId dieses Collaboration Systems. Im Gegensatz zur Variable assetId wird diese nicht durch die assetIds von Threads oder Posts überschrieben.'
  },
  'compensation' => {
    'lastUpdated' => '1239656991',
    'message' => 'Vergütung'
  },
  'compensation.label' => {
    'lastUpdated' => '1236959323',
    'message' => 'Kompensation'
  },
  'content' => {
    'lastUpdated' => '1179751132',
    'message' => 'Der formatierte Inhalt dieses Posts.'
  },
  'content filter' => {
    'lastUpdated' => '1179751146',
    'message' => 'Inhaltsfilter benutzen?'
  },
  'content filter description' => {
    'lastUpdated' => '1179751181',
    'message' => 'Wählen Sie "Ja", um den Inhalt jedes Posts zu filtern.'
  },
  'contentType' => {
    'lastUpdated' => '1179751189',
    'message' => 'Inhalt Typ'
  },
  'controls' => {
    'lastUpdated' => '1179751227',
    'message' => 'Satz an Bearbeitungsicons, um Posts zu löschen oder deren Reihenfolge zu ändern.'
  },
  'cosmetic' => {
    'lastUpdated' => '1179751270',
    'message' => 'Kosmetischer Natur (Rechtschreibfehler, Formatierungsprobleme)'
  },
  'cosmetic.label' => {
    'lastUpdated' => '1179751345',
    'message' => 'Das Wort &quot;Cosmetic (misspelling, formatting problems)&quot;.'
  },
  'critical' => {
    'lastUpdated' => '1179751318',
    'message' => 'Kritisch (funktioniert meistens nicht)'
  },
  'critical.label' => {
    'lastUpdated' => '1286873942',
    'message' => 'Das Wort "Critical (mostly not working)".'
  },
  'date' => {
    'lastUpdated' => '1179751351',
    'message' => 'Datum'
  },
  'date posted' => {
    'lastUpdated' => '1234737784',
    'message' => 'Absende-Datum'
  },
  'date submitted' => {
    'lastUpdated' => '1179751382',
    'message' => 'Datum abgeschickt (submitted)'
  },
  'date updated' => {
    'lastUpdated' => '1179751392',
    'message' => 'Datum Aktualisiert'
  },
  'date.label' => {
    'lastUpdated' => '1179751401',
    'message' => 'Das Wort "Date".'
  },
  'dateSubmitted.human' => {
    'lastUpdated' => '1179751458',
    'message' => 'Das Datum, an dem Post abgeschickt wurde, im &quot;human-readable&quot; Format'
  },
  'dateUpdated.human' => {
    'lastUpdated' => '1179751496',
    'message' => '<p>Datum, an dem Post zuletzt aktualisiert wurde, im &quot;human-readable&quot; Format. <br /></p>'
  },
  'default karma scale' => {
    'lastUpdated' => '1179751521',
    'message' => 'Standard Karma Anzeige'
  },
  'default karma scale help' => {
    'lastUpdated' => '1180075700',
    'message' => 'Dies ist der Standard Wert, der der Karma Anzeige eines Threads zugewiesen wird. Die Karma Anzeige ist ein Bewertungsmechanismus für die Sortierung von Threads, die f&uuml;r Handicaps, Schwierigkeitsgrad, etc. genutzt werden kann.'
  },
  'delete' => {
    'lastUpdated' => '1157903841',
    'message' => 'Löschen'
  },
  'delete.label' => {
    'lastUpdated' => '1179751582',
    'message' => 'Das Wort "Delete".'
  },
  'descending' => {
    'lastUpdated' => '1179751612',
    'message' => 'Absteigend'
  },
  'description' => {
    'lastUpdated' => '1179751622',
    'message' => 'Beschreibung'
  },
  'description.label' => {
    'lastUpdated' => '1179751634',
    'message' => 'Das Wort "Description".'
  },
  'display last reply' => {
    'lastUpdated' => '1179751644',
    'message' => 'Letzte Antwort anzeigen?'
  },
  'display last reply description' => {
    'lastUpdated' => '1179751699',
    'message' => 'Falls auf "Ja" gesetzt, so werden Template Variablen hinzugefügt, die es erlauben, die letzte Antwort dieses Threads anzuzeigen.'
  },
  'displayLastReply' => {
    'lastUpdated' => '1179751783',
    'message' => 'Bedingung, die wahr ist, falls das Collaboration System so konfiguriert ist, dass die letze Antwort angezeigt wird. Falls diese Variable wahr ist, so werden die Collaboration Template Variablen lastReply.* aktiviert.'
  },
  'docs' => {
    'lastUpdated' => '1179751824',
    'message' => 'URL zur Dokumentation über das Format dieser Datei, RSS 2.0 (optionales Feld)'
  },
  'doit' => {
    'lastUpdated' => '1257324379',
    'message' => 'Ein boolcher Wert der wahr ist, wenn eine Suchanfrage eben abgeschickt wurde.'
  },
  'edit' => {
    'lastUpdated' => '1157903827',
    'message' => 'Bearbeiten'
  },
  'edit job' => {
    'lastUpdated' => '1180075770',
    'message' => 'Job Posting bearbeiten'
  },
  'edit link' => {
    'lastUpdated' => '1179751845',
    'message' => 'Bearbeiten Link'
  },
  'edit message' => {
    'lastUpdated' => '1179751855',
    'message' => 'Nachricht bearbeiten'
  },
  'edit question' => {
    'lastUpdated' => '1179751864',
    'message' => 'Frage bearbeiten'
  },
  'edit stamp' => {
    'lastUpdated' => '1179751966',
    'message' => 'Datum letzte Bearbeitung zum Post hinzufügen?'
  },
  'edit stamp description' => {
    'lastUpdated' => '1179751937',
    'message' => 'Wählen Sie "Ja", um jedem Post ein Datum der letzten Bearbeitung hinzuzufügen.'
  },
  'edit submission' => {
    'lastUpdated' => '1180075812',
    'message' => 'Submission bearbeiten'
  },
  'edit timeout' => {
    'lastUpdated' => '1179751982',
    'message' => 'Bearbeiten Timeout'
  },
  'edit timeout description' => {
    'lastUpdated' => '1179752073',
    'message' => 'Wenn diese Zeitspanne überschritten wird, kann der Post nicht mehr durch den urspr&uuml;nglichen Autor bearbeitet werden.'
  },
  'edit.label' => {
    'lastUpdated' => '1179752085',
    'message' => 'Das Wort "Edit".'
  },
  'edit.url' => {
    'lastUpdated' => '1179752101',
    'message' => 'URL zum Bearbeiten des Posts.'
  },
  'editForm archiveEnabled description' => {
    'lastUpdated' => '1217254233',
    'message' => 'Falls Ja, so werden Threads automatisch nach einem bestimmten Zeitintervall versteckt.'
  },
  'editForm archiveEnabled label' => {
    'lastUpdated' => '1217254245',
    'message' => 'Archivierung aktivieren?'
  },
  'enable avatars' => {
    'lastUpdated' => '1179752111',
    'message' => 'Avatare aktivieren?'
  },
  'enable avatars description' => {
    'lastUpdated' => '1179752248',
    'message' => '<p>Wählen Sie &quot;Ja&quot;, um Avatare für Benutzer des Collaboration Systems anzuzeigen. Das Avatar Feld im Benutzerprofile muss dazu aktiviert sein und die Benutzer m&uuml;ssen ein Avatar Bild hochladen, das angezeigt wird.</p><p>Die Benutzung von Avataren hat eine Performance Verschlechterung von Collaboration Systemen zur Folge.</p>'
  },
  'enable metadata' => {
    'lastUpdated' => '1192786357',
    'message' => 'Erlaube Metadaten in Nachrichten'
  },
  'enable metadata description' => {
    'lastUpdated' => '1192978643',
    'message' => 'Wählen Sie "Ja" aus, um Posten MetaData zu erlauben und passiv profiliert zu werden. Das wird die Leistung des Collaboration System komprimieren. MetaData muss auch Seiten weit in den Seite-Einstellungen ermöglicht werden.'
  },
  'epochDate' => {
    'lastUpdated' => '1224835197',
    'message' => 'Veröffentlichungsdatum des Elements als epochales Datum, so dass das Datum Makro für die individuelle Datumsformatierung benutzt werden kann.'
  },
  'every 10 minutes' => {
    'lastUpdated' => '1298376249',
    'message' => 'Alle 10 Minuten'
  },
  'every 15 minutes' => {
    'lastUpdated' => '1298376257',
    'message' => 'Alle 15 Minuten'
  },
  'every 20 minutes' => {
    'lastUpdated' => '1298376264',
    'message' => 'Alle 20 Minuten'
  },
  'every 30 minutes' => {
    'lastUpdated' => '1298376271',
    'message' => 'Alle 30 Minuten'
  },
  'every 5 minutes' => {
    'lastUpdated' => '1298376279',
    'message' => 'Alle 5 Minuten'
  },
  'every hour' => {
    'lastUpdated' => '1298376289',
    'message' => 'Jede Stunde'
  },
  'every minute' => {
    'lastUpdated' => '1298376298',
    'message' => 'Jede Minute'
  },
  'every other hour' => {
    'lastUpdated' => '1298376310',
    'message' => 'Jede andere Stunde'
  },
  'every other minute' => {
    'lastUpdated' => '1298376319',
    'message' => 'Jede andere Minute'
  },
  'fatal' => {
    'lastUpdated' => '1179752284',
    'message' => 'Fatal (Kann nicht weiterarbeiten, bevor dieses Problem gelöst wurde)'
  },
  'fatal.label' => {
    'lastUpdated' => '1179752305',
    'message' => 'Das Wort "Fatal (can\'t continue until this is resolved)".'
  },
  'feed description' => {
    'lastUpdated' => '1217254253',
    'message' => 'Die Beschreibung des RSS Feeds (abgeleitet von der Beschreibung des Collaboration Systems).'
  },
  'feed title' => {
    'lastUpdated' => '1179752372',
    'message' => 'Der Titel des RSS Feeds (abgeleitet vom Titel des Collaboration Systems).'
  },
  'filter code' => {
    'lastUpdated' => '1179752406',
    'message' => 'Filter Kode'
  },
  'filter code description' => {
    'lastUpdated' => '1179752449',
    'message' => 'Setzt die HTML Filterstufe für jeden Post.'
  },
  'flatLayout' => {
    'lastUpdated' => '1179752532',
    'message' => 'Flach'
  },
  'form.footer' => {
    'lastUpdated' => '1257324422',
    'message' => 'HTML-Code der das Suchformular abschließt.'
  },
  'form.header' => {
    'lastUpdated' => '1179752564',
    'message' => 'HTML und Javascript, das für das Funktionieren des Formulars notwendig ist.'
  },
  'form.search' => {
    'lastUpdated' => '1179752612',
    'message' => 'Schaltfläche für das Formular, um mit der Suche zu beginnen.'
  },
  'full text link' => {
    'lastUpdated' => '1179752633',
    'message' => 'URL zum vollständigen Text dieses Elements.'
  },
  'generator' => {
    'lastUpdated' => '1179752675',
    'message' => 'Das Programm zur Generierung des RSS Feeds, zum Beispiel WebGUI plus version information (optionales Feld)'
  },
  'get cs mail' => {
    'lastUpdated' => '1179752760',
    'message' => 'Collaboration System Email bekommen'
  },
  'get mail' => {
    'lastUpdated' => '1179752740',
    'message' => 'Emails benutzen?'
  },
  'get mail help' => {
    'lastUpdated' => '1179752723',
    'message' => 'Wollen Sie, dass dieses Collaboration System die Posts von einem Email Account bekommt?'
  },
  'get mail interval' => {
    'lastUpdated' => '1179752781',
    'message' => 'Nach Emails prüfen alle'
  },
  'get mail interval help' => {
    'lastUpdated' => '1179752827',
    'message' => 'Wie oft soll der Server nach neuen Emails überpr&uuml;ft werden?'
  },
  'group to edit hoverhelp' => {
    'lastUpdated' => '1269421807',
    'message' => 'Eine Gruppe, die die Berechtigung für das Bearbeiten von Beiträgen hat, nachdem diese abgeschickt wurden.'
  },
  'group to edit label' => {
    'lastUpdated' => '1217254306',
    'message' => 'Gruppe fürs Editieren von Posts'
  },
  'guid' => {
    'lastUpdated' => '1179752852',
    'message' => 'Ein eindeutiger Bezeichner für dieses Element.'
  },
  'has posted to one of your subscriptions' => {
    'lastUpdated' => '1234737911',
    'message' => 'hat einen Beitrag zu einem Ihrer Abonnements geschickt.'
  },
  'hideProfileUrl' => {
    'lastUpdated' => '1254901067',
    'message' => 'Eine Bedingung die wahr ist, wenn der Verfasser oder der aktuelle Nutzer "Besucher" ist. Im ersten Fall ist das Besucher-Profil nicht sichtbar, im zweiten Fall ist der Besucher nicht berechtigt, die anderen Profile einzusehen.'
  },
  'id' => {
    'lastUpdated' => '1179752865',
    'message' => 'Die assetId dieses Posts.'
  },
  'image' => {
    'lastUpdated' => '1179752871',
    'message' => 'Bild'
  },
  'image.label' => {
    'lastUpdated' => '1179752881',
    'message' => 'Das Wort "Bild".'
  },
  'image.url' => {
    'lastUpdated' => '1179752920',
    'message' => 'URL zum ersten angehängten Bild (falls dieser Post Anh&auml;nge besitzt).'
  },
  'isFifth' => {
    'lastUpdated' => '1179752966',
    'message' => 'Bedingung, die wahr ist, falls dieser Post der fünfte in diesem Collaboration System ist.'
  },
  'isFourth' => {
    'lastUpdated' => '1179752981',
    'message' => 'Bedingung, die wahr ist, falls dieser Post der vierte in diesem Collaboration System ist.'
  },
  'isSecond' => {
    'lastUpdated' => '1179752994',
    'message' => 'Bedingung, die wahr ist, falls dieser Post der zweite in diesem Collaboration System ist.'
  },
  'isThird' => {
    'lastUpdated' => '1179753009',
    'message' => 'Bedingung, die wahr ist, falls dieser Post der dritte in diesem Collaboration System ist.'
  },
  'item description' => {
    'lastUpdated' => '1179753045',
    'message' => 'Zusammenfassende Beschreibung dieses Elements.'
  },
  'item_loop' => {
    'lastUpdated' => '1179753077',
    'message' => 'Schleife über alle Posts, die in diesen RSS Feed &uuml;bertragen werden.'
  },
  'job description' => {
    'lastUpdated' => '1179753087',
    'message' => 'Job Beschreibung'
  },
  'job requirements' => {
    'lastUpdated' => '1179753100',
    'message' => 'Job Voraussetzungen'
  },
  'job title' => {
    'lastUpdated' => '1179753106',
    'message' => 'Job Titel'
  },
  'job.description.label' => {
    'lastUpdated' => '1226872773',
    'message' => 'Stellenbeschreibung'
  },
  'job.header.label' => {
    'lastUpdated' => '1226872859',
    'message' => 'Bearbeiten offene Stelle'
  },
  'job.requirements.label' => {
    'lastUpdated' => '1226872883',
    'message' => 'Anforderungen'
  },
  'job.title.label' => {
    'lastUpdated' => '1226872929',
    'message' => 'Offene Stelle'
  },
  'karma rank' => {
    'lastUpdated' => '1179753170',
    'message' => 'Karma Rang'
  },
  'karma rating multiplier' => {
    'lastUpdated' => '1180075973',
    'message' => 'Karma für orig. Poster, falls bewertet wird'
  },
  'karma rating multiplier description' => {
    'lastUpdated' => '1180075935',
    'message' => 'Falls das Karma System auf ihrer Site aktiviert ist, ist dies die Menge an Karma, die der originale Autor des Posts bekommt, falls ein anderer Benutzer seine Bewertung für diese Post abgibt.'
  },
  'karma scale' => {
    'lastUpdated' => '1180075983',
    'message' => 'Karma Anzeige'
  },
  'karma spent to rate' => {
    'lastUpdated' => '1180076214',
    'message' => 'Karma Bewertungsgebühr'
  },
  'karma spent to rate description' => {
    'lastUpdated' => '1180076195',
    'message' => 'Falls das Karma System auf ihrer Site aktiviert ist, ist dies die Menge an Karma, die dem Bewerter eines Posts von seinem Karma abgezogen wird, sozusagen als Bewertungsgebühr. Soll die Benutzer davon abhalten, einfach alles zu bewerten, ohne dar&uuml;ber nachzudenken.'
  },
  'karma/post' => {
    'lastUpdated' => '1180076237',
    'message' => 'Karma pro Post'
  },
  'karma/post description' => {
    'lastUpdated' => '1180076287',
    'message' => 'Falls das Karma System auf ihrer Site aktiviert ist, ist dies die Menge an Karma, die ein Benutzer für das Posten einer Nachricht bekommt.'
  },
  'karmaIsEnabled' => {
    'lastUpdated' => '1180076317',
    'message' => 'Boolscher Wert, der angibt, ob das Karma System auf ihrer Site aktiviert ist.'
  },
  'karmaRank.label' => {
    'lastUpdated' => '1257324442',
    'message' => 'Der Ausdruck "Karma-Rang"'
  },
  'karmascale.label' => {
    'lastUpdated' => '1257324472',
    'message' => 'Der Ausdruck "Karma-Skala"'
  },
  'keywords label' => {
    'lastUpdated' => '1221215626',
    'message' => 'Name des Schlüsselworts'
  },
  'keywords.label' => {
    'lastUpdated' => '1257324484',
    'message' => 'Das Wort "Schlüsselworte"'
  },
  'lastBuildDate' => {
    'lastUpdated' => '1179753233',
    'message' => 'Datum, an dem dieser Feed zum letzen Mal aktualisiert wurde. (optionales Feld)'
  },
  'lastReply' => {
    'lastUpdated' => '1179753276',
    'message' => 'Letzte Antwort'
  },
  'lastReply.dateSubmitted.human' => {
    'lastUpdated' => '1179753323',
    'message' => 'Datum, an dem die letzte Antwort abgeschickt wurde, im &quot;human-readable&quot; Format.'
  },
  'lastReply.hideProfileUrl' => {
    'lastUpdated' => '1254901120',
    'message' => 'Eine Bedingung die wahr ist, wenn der Verfasser der letzten Antwort oder der aktuelle Nutzer "Besucher" ist. Im ersten Fall ist das Besucher-Profil nicht sichtbar, im zweiten Fall ist der Besucher nicht berechtigt, die anderen Profile einzusehen.'
  },
  'lastReply.label' => {
    'lastUpdated' => '1179753344',
    'message' => 'Die Phrase "Last Reply".'
  },
  'lastReply.timeSubmitted.human' => {
    'lastUpdated' => '1179753392',
    'message' => 'Der Zeitpunkt, an dem die lezte Antwort abgeschickt wurde, im &quot;human-readable&quot; Format.'
  },
  'lastReply.title' => {
    'lastUpdated' => '1179753405',
    'message' => 'Der Titel der letzten Antwort.'
  },
  'lastReply.url' => {
    'lastUpdated' => '1179753421',
    'message' => 'Url zur letzten Antwort dieses Posts.'
  },
  'lastReply.user.isVisitor' => {
    'lastUpdated' => '1179753467',
    'message' => 'Bedingung, die wahr ist, falls der Urheber der letzten Antwort ein  &quot;Visitor&quot; war.'
  },
  'lastReply.userProfile.url' => {
    'lastUpdated' => '1179753499',
    'message' => 'URL zum Profil des Benutzers, der den letzten Post abgeschickt hat.'
  },
  'lastReply.username' => {
    'lastUpdated' => '1179754058',
    'message' => 'Der Name des Benutzers, der die letzte Antwort abgeschickt hat.'
  },
  'layout' => {
    'lastUpdated' => '1179754079',
    'message' => 'Anordnung'
  },
  'layout.flat.label' => {
    'lastUpdated' => '1179754103',
    'message' => 'Das Wort "Flat".'
  },
  'layout.label' => {
    'lastUpdated' => '1179754118',
    'message' => 'Das Wort "Layout".'
  },
  'layout.nested.label' => {
    'lastUpdated' => '1179754130',
    'message' => 'Das Wort "Nested".'
  },
  'link.header.label' => {
    'lastUpdated' => '1179754143',
    'message' => 'Die Phrase "Edit Link".'
  },
  'location' => {
    'lastUpdated' => '1179754935',
    'message' => 'Standort'
  },
  'location.label' => {
    'lastUpdated' => '1179754945',
    'message' => 'Das Wort "Location".'
  },
  'lock' => {
    'lastUpdated' => '1179754954',
    'message' => 'Sperren'
  },
  'lock.label' => {
    'lastUpdated' => '1236959342',
    'message' => 'Sperren'
  },
  'mail' => {
    'lastUpdated' => '1179754994',
    'message' => 'Email'
  },
  'mail account' => {
    'lastUpdated' => '1179755003',
    'message' => 'Account'
  },
  'mail account help' => {
    'lastUpdated' => '1179755035',
    'message' => 'Account Name (Benutzername / Email Adresse) für die Anmeldung am Email Server.'
  },
  'mail address' => {
    'lastUpdated' => '1179755044',
    'message' => 'Adresse'
  },
  'mail address help' => {
    'lastUpdated' => '1179755103',
    'message' => 'Email Adresse, an die die Benutzer Emails schicken können,  um Nachrichte zu posten.'
  },
  'mail password' => {
    'lastUpdated' => '1179755112',
    'message' => 'Passwort'
  },
  'mail password help' => {
    'lastUpdated' => '1179755134',
    'message' => 'Account Passwort für die Anmeldung am Email Server.'
  },
  'mail prefix' => {
    'lastUpdated' => '1179755148',
    'message' => 'Präfix'
  },
  'mail prefix help' => {
    'lastUpdated' => '1179755195',
    'message' => 'Dieser Text wird an alle Betreffzeilen der Emails angehängt, die von diesem Collaboration System verschickt werden.'
  },
  'mail server' => {
    'lastUpdated' => '1179755204',
    'message' => 'Server'
  },
  'mail server help' => {
    'lastUpdated' => '1179755228',
    'message' => 'Hostname oder IP Adresse des Email Servers, von dem Emails geholt werden sollen.'
  },
  'max image size' => {
    'lastUpdated' => '1179755274',
    'message' => 'Maximale Bildgröße'
  },
  'max image size help' => {
    'lastUpdated' => '1179755457',
    'message' => 'Setzt die Größe von Bild Anhängen für dieses Collaboration System. Falls auf 0 gesetzt, so wird die Standard Gr&ouml;&szlig;e aus den Einstellungen benutzt. Nachtr&auml;gliches Ändern dieses Parameters &auml;ndert nicht die Gr&ouml;&szlig;e von Bildern, die sich schon im CS befinden. Sie m&uuml;ssen dazu die Bilder nochmals speichern.'
  },
  'message' => {
    'lastUpdated' => '1179755467',
    'message' => 'Nachricht'
  },
  'message.header.label' => {
    'lastUpdated' => '1179755493',
    'message' => 'Die Phrase "Edit Message".'
  },
  'message.label' => {
    'lastUpdated' => '1179755504',
    'message' => 'Das Wort "Message".'
  },
  'minor' => {
    'lastUpdated' => '1179755587',
    'message' => 'Gering (störend aber nicht abträglich)'
  },
  'minor.label' => {
    'lastUpdated' => '1179755611',
    'message' => 'Das Wort &quot;Minor (annoying, but not harmful)&quot;.'
  },
  'nested' => {
    'lastUpdated' => '1179755630',
    'message' => 'Verschachtelt'
  },
  'new window' => {
    'lastUpdated' => '1179755647',
    'message' => 'In einem neuen Fenster öffnen?'
  },
  'newWindow.label' => {
    'lastUpdated' => '1226872987',
    'message' => 'In neues Fenster öffnen?'
  },
  'next' => {
    'lastUpdated' => '1179755679',
    'message' => 'Nächstes'
  },
  'next.label' => {
    'lastUpdated' => '1236959376',
    'message' => 'Nächster'
  },
  'no user email error message' => {
    'lastUpdated' => '1274970687',
    'message' => 'Es konnte kein Benutzer mit dieser E-Mailadresse gefunden werden.'
  },
  'notification template' => {
    'lastUpdated' => '1179755715',
    'message' => 'Collaboration System, Benachrichtung Template'
  },
  'notification template description' => {
    'lastUpdated' => '1179755778',
    'message' => 'Template, das für das Generieren von Nachrichten benutzt wird, die den Benutzern geschickt werden, die dieses Asset abonniert haben.'
  },
  'once per day' => {
    'lastUpdated' => '1298376337',
    'message' => 'Einmal täglich'
  },
  'open' => {
    'lastUpdated' => '1180076325',
    'message' => 'Offen'
  },
  'open.label' => {
    'lastUpdated' => '1179755799',
    'message' => 'Das Wort "Open".'
  },
  'post' => {
    'lastUpdated' => '1179755814',
    'message' => 'Post'
  },
  'post received template' => {
    'lastUpdated' => '1224835238',
    'message' => 'Post empfangen Template'
  },
  'post received template hoverHelp' => {
    'lastUpdated' => '1224835282',
    'message' => 'Das Template für die Nachricht, falls ein Benutzer einen Post erstellt hat.'
  },
  'post template' => {
    'lastUpdated' => '1179755832',
    'message' => 'Collaboration System, Post Formular Template'
  },
  'post template description' => {
    'lastUpdated' => '1179755852',
    'message' => 'Das Template für einen einzelnen Post.'
  },
  'post title' => {
    'lastUpdated' => '1179755869',
    'message' => 'Der Titel des Elements (Post).'
  },
  'post.label' => {
    'lastUpdated' => '1179755878',
    'message' => 'Das Wort "Post".'
  },
  'post_loop' => {
    'lastUpdated' => '1179755923',
    'message' => 'Eine Liste von Posts für dieses Asset.'
  },
  'post_loop_user.isVisitor' => {
    'lastUpdated' => '1254901157',
    'message' => 'Eine Bedingung die wahr ist, wenn der Verfasser "Besucher" ist.'
  },
  'posts/page' => {
    'lastUpdated' => '1179755940',
    'message' => 'Posts pro Seite'
  },
  'posts/page description' => {
    'lastUpdated' => '1179758161',
    'message' => 'Anzahl angezeigter Posts auf jeder Seite im Thread Template. Ein Setzen dieser Zahl auf einen zu hohen Wert kann die Generierung der Seite verlangsamen.'
  },
  'preview' => {
    'lastUpdated' => '1179758171',
    'message' => 'Vorschau'
  },
  'previous' => {
    'lastUpdated' => '1180076337',
    'message' => 'Vorheriger'
  },
  'previous.label' => {
    'lastUpdated' => '1179758194',
    'message' => 'Das Wort "Previous".'
  },
  'pubDate' => {
    'lastUpdated' => '1179758219',
    'message' => 'Das Datum, an dem das Element veröffentlicht wurde.'
  },
  'query.form' => {
    'lastUpdated' => '1180076393',
    'message' => 'HTML Formular für das Hinzuf&uuml;gen eines Feldes, in dem jede Eingabe in passenden Seiten enthalten sein muss.'
  },
  'question' => {
    'lastUpdated' => '1179758247',
    'message' => 'Frage'
  },
  'question.header.label' => {
    'lastUpdated' => '1179758264',
    'message' => 'Die Phrase "Edit Question".'
  },
  'question.label' => {
    'lastUpdated' => '1179758276',
    'message' => 'Das Wort "Question".'
  },
  'rate' => {
    'lastUpdated' => '1179758387',
    'message' => 'Bewerten'
  },
  'rate.label' => {
    'lastUpdated' => '1179758295',
    'message' => 'Das Wort "Rate".'
  },
  'rating' => {
    'lastUpdated' => '1179758378',
    'message' => 'Bewertung'
  },
  'rating.label' => {
    'lastUpdated' => '1179758314',
    'message' => 'Das Wort "Rating".'
  },
  'rating_loop' => {
    'lastUpdated' => '1180076490',
    'message' => 'Schleife, die je einmal für jeden Bewertungspunkt läuft, die der Post hat.'
  },
  'rating_loop.count' => {
    'lastUpdated' => '1180076527',
    'message' => 'Die Index Variabale für <strong>rating_loop</strong>.'
  },
  'read more' => {
    'lastUpdated' => '1157904425',
    'message' => 'mehr...'
  },
  'readmore.label' => {
    'lastUpdated' => '1236959744',
    'message' => 'mehr...'
  },
  'rejected' => {
    'lastUpdated' => '1179758429',
    'message' => 'Abgewiesen'
  },
  'rejected because no user account' => {
    'lastUpdated' => '1179758560',
    'message' => 'Sie dürfen keine Nachrichten posten, da ihr Account f&uuml;r diese Site nicht gefunden werden konnte. Vielleicht ist diese Email Adresse ihrem Account nicht zugeordnet.'
  },
  'rejected because not allowed' => {
    'lastUpdated' => '1179758660',
    'message' => 'Sie dürfen keine Nachrichten posten, da Sie entweder nicht die nötigen Rechte besitzen oder diese Diskussion nicht abonniert haben.'
  },
  'replies' => {
    'lastUpdated' => '1236959764',
    'message' => 'Antworten'
  },
  'replies.label' => {
    'lastUpdated' => '1236959795',
    'message' => 'Reaktionen'
  },
  'reply' => {
    'lastUpdated' => '1179758688',
    'message' => 'Antwort'
  },
  'reply filter code' => {
    'lastUpdated' => '1243495803',
    'message' => 'Antwortfilter-Code'
  },
  'reply filter code description' => {
    'lastUpdated' => '1243114594',
    'message' => 'Level HTML-Filter für eine Antwort.'
  },
  'reply rich editor' => {
    'lastUpdated' => '1243495181',
    'message' => 'Antwort Rich Editor'
  },
  'reply rich editor description' => {
    'lastUpdated' => '1243495212',
    'message' => 'Selektiert den Rich Editor für eine Antwort'
  },
  'reply.label' => {
    'lastUpdated' => '1236959725',
    'message' => 'Antwort'
  },
  'require subscription for email posting' => {
    'lastUpdated' => '1179758756',
    'message' => 'Abonnement erforderlich für das posten per Email?'
  },
  'require subscription for email posting help' => {
    'lastUpdated' => '1179818209',
    'message' => 'Falls hier "Ja" gesetzt ist, muss sich der Benutzer nicht nur in der richtigen Gruppe befinden, sondern auch das Collaboration System oder den Thread abonnieren, um posten zu können.'
  },
  'responses' => {
    'lastUpdated' => '1236959698',
    'message' => 'Reaktionen'
  },
  'responses.label' => {
    'lastUpdated' => '1236959682',
    'message' => 'Reaktionen'
  },
  'rich editor' => {
    'lastUpdated' => '1179818246',
    'message' => 'Rich Editor'
  },
  'rich editor description' => {
    'lastUpdated' => '1193050243',
    'message' => 'Wählen Sie welcher "Rich Editor" für den Inhalt von Posts verwendet werden soll.'
  },
  'rss template' => {
    'lastUpdated' => '1179818314',
    'message' => 'Collaboration System RSS Template'
  },
  'rss template description' => {
    'lastUpdated' => '1179818355',
    'message' => 'Template zum Generieren von XML für RSS Feeds, basierend auf diesem Asset.'
  },
  'rss.url' => {
    'lastUpdated' => '1179818383',
    'message' => 'URL für den Download der RSS Zusammenfassung dieses Assets.'
  },
  'search' => {
    'lastUpdated' => '1179818391',
    'message' => 'Suche'
  },
  'search template' => {
    'lastUpdated' => '1179818407',
    'message' => 'Collaboration System Suche Template'
  },
  'search template description' => {
    'lastUpdated' => '1179818452',
    'message' => 'Template für das Suchformular und dessen Ergebnisse dieses Collaboration System Assets.'
  },
  'search.label' => {
    'lastUpdated' => '1226873018',
    'message' => 'Suchen'
  },
  'search.url' => {
    'lastUpdated' => '1179818489',
    'message' => 'URL zum Suche Formular dieses Collaboration System Assets.'
  },
  'sequence' => {
    'lastUpdated' => '1179818498',
    'message' => 'Sequenz'
  },
  'severity' => {
    'lastUpdated' => '1236959634',
    'message' => 'Priorität'
  },
  'severity.label' => {
    'lastUpdated' => '1236959647',
    'message' => 'Priorität'
  },
  'sort by' => {
    'lastUpdated' => '1179818544',
    'message' => 'Sortiere nach'
  },
  'sort by description' => {
    'lastUpdated' => '1276643070',
    'message' => 'Alle Beiträge werden standardmässig in geordneter Reihenfolge angezeigt. Benutzen Sie dieses Feld, um die Eigenschaft auszuwählen, nach der sortiert werden soll. '
  },
  'sort order' => {
    'lastUpdated' => '1179818674',
    'message' => 'Sortierungsreihenfolge'
  },
  'sort order description' => {
    'lastUpdated' => '1179818688',
    'message' => 'Sortiere auf- oder absteigend.'
  },
  'sortby.date.url' => {
    'lastUpdated' => '1179818712',
    'message' => 'URL, um Post nach dem Erstellungsdatum zu sortieren.'
  },
  'sortby.karmaRank.url' => {
    'lastUpdated' => '1179818753',
    'message' => 'URL, um Posts nach deren Karma Ranking zu sortieren. Karma wurde den Threads von verschiedenen Benutzern zugesprochen.'
  },
  'sortby.lastreply.url' => {
    'lastUpdated' => '1179818779',
    'message' => 'URL, um Post nach dem Datum der letzten Aktualisierung zu sortieren.'
  },
  'sortby.rating.url' => {
    'lastUpdated' => '1179818805',
    'message' => 'URL, um Posts nach deren Beurteilung zu sortieren.'
  },
  'sortby.replies.url' => {
    'lastUpdated' => '1179818829',
    'message' => 'URL, um Posts nach der Anzahl ihrer Antworten zu sortieren.'
  },
  'sortby.title.url' => {
    'lastUpdated' => '1179818849',
    'message' => 'URL, um Posts nach deren Titel zu sortieren.'
  },
  'sortby.username.url' => {
    'lastUpdated' => '1179818874',
    'message' => 'URL, um Posts nach dem Benutzernamen der Erzeuger zu sortieren.'
  },
  'sortby.views.url' => {
    'lastUpdated' => '1179818917',
    'message' => 'URL, um Posts nach der Anzahl der Ansichten zu sortieren (Wie oft wurde ein Post von einem anderen Benutzer gelesen).'
  },
  'status' => {
    'lastUpdated' => '1179818925',
    'message' => 'Status'
  },
  'status.label' => {
    'lastUpdated' => '1236959396',
    'message' => 'Status'
  },
  'stick.label' => {
    'lastUpdated' => '1179818959',
    'message' => 'Die Phrase "Make Sticky".'
  },
  'sticky' => {
    'lastUpdated' => '1180076580',
    'message' => 'Als "Sticky" markieren'
  },
  'subject' => {
    'lastUpdated' => '1179818971',
    'message' => 'Betreff'
  },
  'subject.label' => {
    'lastUpdated' => '1236959605',
    'message' => 'Betreff'
  },
  'submission.header.label' => {
    'lastUpdated' => '1179818998',
    'message' => 'Die Phrase "Edit Submission".'
  },
  'subscribe' => {
    'lastUpdated' => '1179819005',
    'message' => 'Abonnieren'
  },
  'subscribe.label' => {
    'lastUpdated' => '1236959592',
    'message' => 'Abonnieren'
  },
  'subscribe.url' => {
    'lastUpdated' => '1179819071',
    'message' => 'URL, um ein Collaboration System Asset zu abonnieren. Falls neuer Inhalt dem Asset hinzugefügt wird, wird der Benutzer dar&uuml;ber informiert.'
  },
  'subscription group hoverHelp' => {
    'lastUpdated' => '1193050345',
    'message' => 'Verwalten der Benutzer in der Subscription Gruppe des Collaboration Systems'
  },
  'subscription group label' => {
    'lastUpdated' => '1193051910',
    'message' => 'Subscription Group
'
  },
  'synopsis' => {
    'lastUpdated' => '1179819082',
    'message' => 'Zusammenfassung'
  },
  'synopsis.label' => {
    'lastUpdated' => '1236959576',
    'message' => 'Zusammenfassung'
  },
  'system template' => {
    'lastUpdated' => '1179819109',
    'message' => 'Collaboration System Template'
  },
  'system template description' => {
    'lastUpdated' => '1179819131',
    'message' => 'Dies ist das Haupttemplate für das Collaboration System.'
  },
  'thread approval workflow' => {
    'lastUpdated' => '1193051928',
    'message' => 'Thread Approval Workflow'
  },
  'thread approval workflow description' => {
    'lastUpdated' => '1193052107',
    'message' => 'Wählen Sie einen Workflow der bei jedem Thread ausgeführt wird, wenn er übermittelt wird.'
  },
  'thread template' => {
    'lastUpdated' => '1179819144',
    'message' => 'Collaboration System Thread Template'
  },
  'thread template description' => {
    'lastUpdated' => '1179819161',
    'message' => 'Template für die Anzeige eines Threads.'
  },
  'threads/page' => {
    'lastUpdated' => '1179819173',
    'message' => 'Threads pro Seite'
  },
  'threads/page description' => {
    'lastUpdated' => '1179819232',
    'message' => 'Anzahl der Threads, die auf jeder Seite angezeigt werden. Falls Sie diese Zahl sehr hoch setzen, kann dies die Generierung der Seite verlangsamen.'
  },
  'thumbnail' => {
    'lastUpdated' => '1179819243',
    'message' => 'Thumbnail'
  },
  'thumbnail size' => {
    'lastUpdated' => '1179819277',
    'message' => 'Größe des Thumbnails'
  },
  'thumbnail size help' => {
    'lastUpdated' => '1179819467',
    'message' => 'Setzt die Größe von Thumbnails für dieses Collaboration System. Falls hier auf 0 gesetzt, wird die Standard Einstellung benutzt. Au&szlig;erdem wird die Gr&ouml;&szlig;e der schon im CS enthaltenen Thumbnails nicht nachträglich ge&auml;ndert, falls Sie hier einen anderen Wert setzen. Wollen Sie dies, m&uuml;&szlig;en Sie die schon vorhandenen Thumbnails nochmal speichern.'
  },
  'thumbnail.label' => {
    'lastUpdated' => '1236959558',
    'message' => 'Thumbnail'
  },
  'timeSubmitted.human' => {
    'lastUpdated' => '1179819517',
    'message' => 'Zeitpunkt, an dem Post erzeugt wurde, im "human-readable" Format.'
  },
  'timeUpdated.human' => {
    'lastUpdated' => '1179819546',
    'message' => 'Zeitpunkt, an dem Post zum letzten Mal aktualisiert wurde, im "human-readable" Format.'
  },
  'title' => {
    'lastUpdated' => '1179819560',
    'message' => 'Titel'
  },
  'title.label' => {
    'lastUpdated' => '1236959406',
    'message' => 'Titel'
  },
  'tmplVar status' => {
    'lastUpdated' => '1179819586',
    'message' => 'Der Status des Posts.'
  },
  'tmplVar thumbnail' => {
    'lastUpdated' => '1179819668',
    'message' => 'URL zum Thumbnail des ersten Bildes im Anhang (falls Post Anhänge besitzt).'
  },
  'tmplVar url' => {
    'lastUpdated' => '1179819678',
    'message' => 'URL des Posts.'
  },
  'transfer karma' => {
    'lastUpdated' => '1179819692',
    'message' => 'Karma übertragen'
  },
  'transferkarma.label' => {
    'lastUpdated' => '1257324509',
    'message' => 'Der Ausdruck "Karma übertragen"'
  },
  'unarchive' => {
    'lastUpdated' => '1179819716',
    'message' => 'Archivieren rückgängig machen'
  },
  'unarchive all' => {
    'lastUpdated' => '1257324535',
    'message' => 'Archivierung aller Threads rückgängig machen'
  },
  'unarchive confirm' => {
    'lastUpdated' => '1257324596',
    'message' => 'Sind sie sicher? Jeder Thread nach dem "Archiviere nach"-Intervall wird zurück-archiviert werden.'
  },
  'unlock' => {
    'lastUpdated' => '1236959530',
    'message' => 'Entsperren'
  },
  'unlock.label' => {
    'lastUpdated' => '1236959505',
    'message' => 'Entsperren'
  },
  'unstick' => {
    'lastUpdated' => '1180076597',
    'message' => '"Sticky" Markierung entfernen'
  },
  'unstick.label' => {
    'lastUpdated' => '1179819768',
    'message' => 'Das Wort "Unstick".'
  },
  'unsubscribe' => {
    'lastUpdated' => '1179819803',
    'message' => 'Abbestellen'
  },
  'unsubscribe formEmail' => {
    'lastUpdated' => '1274268349',
    'message' => 'Ein Textformular mit E-Mail-Vervollständigung.'
  },
  'unsubscribe formFooter' => {
    'lastUpdated' => '1274970800',
    'message' => 'HTML-Code, der das Abbestellen-Formular beendet.'
  },
  'unsubscribe formHeader' => {
    'lastUpdated' => '1274970810',
    'message' => 'HTML-Code, der das Abbestellen-Formular einleitet.'
  },
  'unsubscribe formMessage' => {
    'lastUpdated' => '1274268448',
    'message' => 'Internationalisierte Nachrichten an den Benutzer über Fehler oder Erfolg.'
  },
  'unsubscribe formSubmit' => {
    'lastUpdated' => '1274970833',
    'message' => 'Ein Button, um das Formular abzusenden.'
  },
  'unsubscribe instructions' => {
    'lastUpdated' => '1274970855',
    'message' => 'Bitte geben Sie die E-Mail-Adresse des Benutzers ein, der abbestellen möchte.'
  },
  'unsubscribe template' => {
    'lastUpdated' => '1274268514',
    'message' => 'Abbestellen-Template'
  },
  'unsubscribe template hoverHelp' => {
    'lastUpdated' => '1274970901',
    'message' => 'Wählen Sie ein Template, um einem nicht eingeloggten Benutzer dabei zu helfen, ein CS oder einen Thread darin abzubestellen.'
  },
  'unsubscribe.label' => {
    'lastUpdated' => '1236959420',
    'message' => 'Abbestellen'
  },
  'unsubscribe.url' => {
    'lastUpdated' => '1179819851',
    'message' => 'URL, um Abonnement abzubestellen.'
  },
  'url' => {
    'lastUpdated' => '1179819858',
    'message' => 'URL'
  },
  'url.label' => {
    'lastUpdated' => '1236959486',
    'message' => 'URL'
  },
  'use captcha hover help' => {
    'lastUpdated' => '1193051884',
    'message' => 'Wählen Sie wer die Menschlichkeitskontrolle der Benutzer macht,
bevor diesen erlaubt wird in das Collaboration System zu posten.'
  },
  'use captcha label' => {
    'lastUpdated' => '1193051684',
    'message' => 'Benutze Post Capcha'
  },
  'use preview' => {
    'lastUpdated' => '1179819880',
    'message' => 'Vorschau benutzen?'
  },
  'use preview description' => {
    'lastUpdated' => '1179819964',
    'message' => 'Wählen Sie hier "Ja", um den Benutzer eine Vorschau seines Posts zu pr&auml;sentieren, bevor dieser abgeschickt wird. W&auml;hrend die Vorschau angezeigt wird, kann der Post entweder bearbeitet oder abgebrochen werden.'
  },
  'user' => {
    'lastUpdated' => '1168864618',
    'message' => 'Benutzer '
  },
  'user defined 1' => {
    'lastUpdated' => '1179819991',
    'message' => 'Benutzerdefiniert 1'
  },
  'user defined 2' => {
    'lastUpdated' => '1179819999',
    'message' => 'Benutzerdefiniert 2'
  },
  'user defined 3' => {
    'lastUpdated' => '1179820010',
    'message' => 'Benutzerdefiniert 3'
  },
  'user defined 4' => {
    'lastUpdated' => '1179820020',
    'message' => 'Benutzerdefiniert 4'
  },
  'user defined 5' => {
    'lastUpdated' => '1179820028',
    'message' => 'Benutzerdefiniert 5'
  },
  'user.canPost' => {
    'lastUpdated' => '1179820035',
    'message' => 'Bedingung, die wahr ist wenn aktueller Benutzer Beiträge zu diesem Collaboration Asset hinzufügen darf. '
  },
  'user.canStartThread' => {
    'lastUpdated' => '1257324641',
    'message' => 'Eine Bedingung die wahr ist, wenn der aktuelle Nutzer Threads in diesem Kollaborations-Asset hinzufügen darf.'
  },
  'user.hasRead' => {
    'lastUpdated' => '1179820776',
    'message' => 'Bedingung, die angibt, ob ein Benutzer diesen Thread gelesen hat.'
  },
  'user.isModerator' => {
    'lastUpdated' => '1179820808',
    'message' => 'Bedingung, die wahr ist, falls der aktuelle Benutzer der Moderator dieses Assets ist.'
  },
  'user.isPoster' => {
    'lastUpdated' => '1179820840',
    'message' => 'Bedingung, die wahr ist, falls der aktuelle Benutzer diesen Post abgeschickt hat.'
  },
  'user.isSubscribed' => {
    'lastUpdated' => '1179820861',
    'message' => 'Bedingung, die wahr ist, falls der aktuelle Benutzer dieses Collaboration System Asset abonniert hat.'
  },
  'user.isVisitor' => {
    'lastUpdated' => '1179820878',
    'message' => 'Bedingung, die wahr ist, falls der Poster ein Visitor ist.'
  },
  'user.label' => {
    'lastUpdated' => '1236959450',
    'message' => 'Benutzer'
  },
  'userProfile.url' => {
    'lastUpdated' => '1179820907',
    'message' => 'URL zum Profil des Benutzers, der den Post abgeschickt hat.'
  },
  'views' => {
    'lastUpdated' => '1180076607',
    'message' => 'Ansichten'
  },
  'views.label' => {
    'lastUpdated' => '1236959439',
    'message' => 'Ansichten'
  },
  'visitor' => {
    'lastUpdated' => '1179820932',
    'message' => 'Visitor Name'
  },
  'visitor cache timeout' => {
    'lastUpdated' => '1179820942',
    'message' => 'Visitor Cache Timeout'
  },
  'visitor cache timeout help' => {
    'lastUpdated' => '1179820987',
    'message' => 'Alle Visitors sehen das Asset auf die gleiche Weise, man kann dies also cachen. Wie lange soll das Asset gecached werden.'
  },
  'visitorName.label' => {
    'lastUpdated' => '1236959471',
    'message' => 'Besuchername'
  },
  'webMaster' => {
    'lastUpdated' => '1179821057',
    'message' => 'Die Email Adresse der Person, die für die Technik, die diesen RSS Feed betrifft, verantwortlich ist. (Optionales Feld)'
  },
  'who posts' => {
    'lastUpdated' => '1178626772',
    'message' => 'Wer darf Beiträge veröffentlichen?'
  },
  'who posts description' => {
    'lastUpdated' => '1168864750',
    'message' => 'Gruppe, die Beiträge veröffentlichen darf.<br />'
  },
  'who threads' => {
    'lastUpdated' => '1193051651',
    'message' => 'Wer kann einen Thread posten?'
  },
  'who threads description' => {
    'lastUpdated' => '1193051588',
    'message' => 'Der Gruppe wird erlaubt einen Threat in diesem Asset zu starten.'
  }
}
;

1;
